summaryrefslogtreecommitdiff
path: root/sdl_android/src/main/java/com/smartdevicelink/proxy
diff options
context:
space:
mode:
authorJoey Grover <joeygrover@gmail.com>2017-10-12 14:34:53 -0400
committerJoey Grover <joeygrover@gmail.com>2017-10-12 14:34:53 -0400
commit3a403034a7603c72763c3918288cd3230f1f32ea (patch)
tree88a9e865b6c0645de82af10d2a5822fb7197a19e /sdl_android/src/main/java/com/smartdevicelink/proxy
parentd6096fd37ece934f0075f669e3ce584f94d68c2f (diff)
downloadsdl_android-3a403034a7603c72763c3918288cd3230f1f32ea.tar.gz
Reduced min SDK version on virtual display encoder from 21 to 19
Should cover +90% of all phones at time of commit
Diffstat (limited to 'sdl_android/src/main/java/com/smartdevicelink/proxy')
-rw-r--r--sdl_android/src/main/java/com/smartdevicelink/proxy/SdlProxyBase.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/sdl_android/src/main/java/com/smartdevicelink/proxy/SdlProxyBase.java b/sdl_android/src/main/java/com/smartdevicelink/proxy/SdlProxyBase.java
index d924f88cd..e1e80d5a0 100644
--- a/sdl_android/src/main/java/com/smartdevicelink/proxy/SdlProxyBase.java
+++ b/sdl_android/src/main/java/com/smartdevicelink/proxy/SdlProxyBase.java
@@ -4037,7 +4037,7 @@ public abstract class SdlProxyBase<proxyListenerType extends IProxyListenerBase>
}
/**
* Starts streaming a remote display to the module if there is a connected session. This method of streaming requires the device to be on API level 21 or higher
* @param context a context that can be used to create the remote display
* @param remoteDisplay class object of the remote display. This class will be used to create an instance of the remote display and will be projected to the module
* @param parameters streaming parameters to be used when streaming. If null is sent in, the default/optimized options will be used.
@@ -4046,7 +4046,7 @@ public abstract class SdlProxyBase<proxyListenerType extends IProxyListenerBase>
*
* @param encrypted a flag of if the stream should be encrypted. Only set if you have a supplied encryption library that the module can understand.
*/
- @TargetApi(21)
+ @TargetApi(19)
public void startRemoteDisplayStream(Context context, final Class<? extends SdlRemoteDisplay> remoteDisplay, final VideoStreamingParameters parameters, final boolean encrypted){
if(getWiProVersion() >= 5 && !_systemCapabilityManager.isCapabilitySupported(SystemCapabilityType.VIDEO_STREAMING)){
Log.e(TAG, "Video streaming not supported on this module");
@@ -6231,7 +6231,7 @@ public abstract class SdlProxyBase<proxyListenerType extends IProxyListenerBase>
* VideoStreamingManager houses all the elements needed to create a scoped, streaming manager for video projection. It is only a private, instance
* dependant class at the moment until it can become public. Once the class is public and API defined, it will be moved into the SdlSession class
*/
- @TargetApi(21)
+ @TargetApi(19)
private class VideoStreamingManager implements ISdlServiceListener{
Context context;
ISdl internalInterface;
@@ -6276,6 +6276,7 @@ public abstract class SdlProxyBase<proxyListenerType extends IProxyListenerBase>
} catch (Exception e) {
e.printStackTrace();
}
+ Log.d(TAG, parameters.toString());
}
public void stopStreaming(){
@@ -4037,7 +4037,7 @@ public abstract class SdlProxyBase<proxyListenerType extends IProxyListenerBase>
}
/**
- * Starts streaming a remote display to the module if there is a connected session. This method of streaming requires the device to be on API level 21 or higher
+ * Starts streaming a remote display to the module if there is a connected session. This method of streaming requires the device to be on API level 19 or higher
* @param context a context that can be used to create the remote display
* @param remoteDisplay class object of the remote display. This class will be used to create an instance of the remote display and will be projected to the module